dupin.data.spatial
----------------------------

.. rubric:: Overview

.. py:currentmodule:: dupin.data.spatial

.. autosummary::
    :nosignatures:

    NeighborAveraging

.. rubric:: Details

.. automodule:: dupin.data.spatial
    :synopsis: Classes for performing spatial averaging over distributions across space.
    :members: NeighborAveraging
